@@ -452,7 +452,10 @@ class CatalogObjectReference(Attribute):
 
         See :meth:`Attribute.serialize`.
         """
-        return value.serialize(modified_only=False, jsonapi_format=jsonapi_format)
+        if hasattr(value, "serialize"):
+            return value.serialize(modified_only=False, jsonapi_format=jsonapi_format)
+        else:
+            return value
 
 
 class Timestamp(Attribute):
@@ -754,6 +757,7 @@ class AttributeMeta(type):
 
     _KEY_ATTR_TYPES = "_attribute_types"
     _KEY_REF_ATTR_TYPES = "_reference_attribute_types"
+    _KEY_V1_PROPERTIES = "v1_properties"
 
     def __new__(cls, name, bases, attrs):
         types = {}
@@ -786,7 +790,9 @@ class AttributeMeta(type):
                     if attr_name not in references:
                         references[attr_name] = attr_type
 
-        attrs["ATTRIBUTES"] = tuple(types.keys())
+        attrs["ATTRIBUTES"] = tuple(
+            k for k in types.keys() if k != AttributeMeta._KEY_V1_PROPERTIES
+        )
         attrs[AttributeMeta._KEY_ATTR_TYPES] = types
         attrs[AttributeMeta._KEY_REF_ATTR_TYPES] = references
 
@@ -915,8 +921,10 @@ class MappingAttribute(ModelAttribute, AttributeEqualityMixin, metaclass=Attribu
         if isinstance(attrs, MappingAttribute):
             # mapping attribute objects hold their own state
             data = attrs._attributes
-        else:
+        elif isinstance(attrs, Mapping):
             data = attrs
+        else:
+            return attrs
 
         serialized = {}
         for name, value in data.items():
