@@ -13,9 +13,9 @@
 # limitations under the License.
 
 from .metadata import Metadata
-from ....common.property_filtering import GenericProperties
+from ....common.property_filtering import Properties
 
 
-properties = GenericProperties()
+properties = Properties()
 
 __all__ = ["Metadata", "properties"]
