@@ -13,19 +13,19 @@ raster services that makes most interactions easier.
 It's available under ``descarteslabs.scenes``.
 """
 
-from .geocontext import AOI, DLTile, XYZTile, GeoContext
-from ._display import display, save_image
-from ._search import (
-    search,
+from ..common.geo import AOI, DLTile, XYZTile, GeoContext
+from ..common.collection import Collection
+from ..common.display import display, save_image
+from .search_api import (
     get_product,
     get_band,
     get_derived_band,
+    search,
     search_products,
     search_bands,
     search_derived_bands,
 )
 from .scene import Scene
-from .collection import Collection
 from .scenecollection import SceneCollection
 
 __all__ = [
