@@ -24,10 +24,14 @@ import threading
 import warnings
 from hashlib import sha1
 
-import requests
 from descarteslabs.exceptions import AuthError, OauthError
-from requests.adapters import HTTPAdapter
-from urllib3.util.retry import Retry
+
+try:
+    # public client
+    from .._dl_modules.common.http import Retry, Session
+except ImportError:
+    # inside monorepo
+    from ..common.http import Retry, Session
 
 
 # copied from descarteslabs/common/threading/local.py, but we need
@@ -104,6 +108,17 @@ def makedirs_if_not_exists(path):
                 raise
 
 
+def get_default_domain():
+    # See if we know the environment we're in, and if so use the
+    # correct `iam_url`. Use a default if we don't know the environment
+    from descarteslabs.config import peek_settings
+
+    class DummyAuth:
+        payload = {}
+
+    return peek_settings(auth=DummyAuth()).iam_url
+
+
 class Auth:
     """Client used to authenticate with all Descartes Labs service APIs."""
 
@@ -114,8 +129,6 @@ class Auth:
         status_forcelist=[429, 500, 502, 503, 504],
     )
 
-    ADAPTER = ThreadLocalWrapper(lambda: HTTPAdapter(max_retries=Auth.RETRY_CONFIG))
-
     AUTHORIZATION_ERROR = (
         "No valid authentication info found{}. "
         "See https://docs.descarteslabs.com/authentication.html."
@@ -150,7 +163,7 @@ class Auth:
 
     def __init__(
         self,
-        domain="https://accounts.descarteslabs.com",
+        domain=None,
         scope=None,
         leeway=500,
         token_info_path=_default_token_info_path,
@@ -211,7 +224,7 @@ class Auth:
         Parameters
         ----------
 
-        domain : str, default ``https://accounts.descarteslabs.com``
+        domain : str, default ``descarteslabs.config.get_settings().IAM_URL``
             The domain used for the credentials. You should normally never
             change this.
         scope : list(str), optional
@@ -235,7 +248,7 @@ class Auth:
             The JWT client id. If provided it will take precedence over the
             corresponding environment variable, or the credentials retrieved through
             the file specified in ``token_info_path``. If this parameter is provided,
-            you **must** either provide a ``client_id`` or ``refresh_token`` (but not
+            you **must** either provide a ``client_secret`` or ``refresh_token`` (but not
             both). Access tokens retrieved this way will be cached without revealing
             the client secret.
         client_secret : str, optional
@@ -461,15 +474,17 @@ class Auth:
         self._namespace = None
 
         if retries is None:
-            self._adapter = self.ADAPTER
-        else:
-            self.RETRY_CONFIG = retries
-            self._init_adapter()
+            retries = self.RETRY_CONFIG
 
+        self._retry_config = retries
         self._init_session()
-        self.domain = domain
         self.leeway = leeway
 
+        if domain is None:
+            domain = get_default_domain()
+
+        self.domain = domain
+
     @classmethod
     def from_environment_or_token_json(cls, **kwargs):
         """Creates an Auth object from the given arguments.
@@ -481,11 +496,6 @@ class Auth:
         """
         return Auth(**kwargs)
 
-    def _init_adapter(self):
-        self._adapter = ThreadLocalWrapper(
-            lambda: HTTPAdapter(max_retries=self.RETRY_CONFIG)
-        )
-
     def _init_session(self):
         # Sessions can't be shared across threads or processes because the underlying
         # SSL connection pool can't be shared. We create them thread-local to avoid
@@ -587,9 +597,7 @@ class Auth:
         return self._session.get()
 
     def build_session(self):
-        session = requests.Session()
-        session.mount("https://", self.ADAPTER.get())
-        return session
+        return Session(self.domain, retries=self._retry_config)
 
     @staticmethod
     def get_default_auth():
@@ -614,6 +622,9 @@ class Auth:
 
     @staticmethod
     def _read_token_info(path, suppress_warning=False):
+        if os.environ.get("DESCARTESLABS_NO_JWT_CACHE", "").lower() == "true":
+            return {}
+
         try:
             with open(path) as fp:
                 return json.load(fp)
@@ -715,7 +726,7 @@ class Auth:
             if self.scope is not None:
                 params[self.KEY_SCOPE] = " ".join(self.scope)
 
-        r = self.session.post(self.domain + "/token", json=params, timeout=timeout)
+        r = self.session.post("/token", json=params, timeout=timeout)
 
         if r.status_code != 200:
             raise OauthError("Could not retrieve token: {}".format(r.text.strip()))
@@ -781,7 +792,6 @@ class Auth:
         for name, value in state.items():
             setattr(self, name, value)
 
-        self._init_adapter()
         self._init_session()
 
 
